@@ -17,7 +17,7 @@ def download_and_extract(url, replace=False, cache=None, all=False, src=False):
         from cStringIO import StringIO as BytesIO
     from hashlib import md5
     from os import makedirs
-    from os.path import abspath, dirname, exists, join
+    from os.path import dirname, exists, join
     from pkg_resources import resource_filename
     from shutil import copyfileobj, rmtree
     try:
